<?php
/**
 * This file contains the FormWizard class.
 *
 * $Id: FormWizard.inc,v 1.2 2003/07/31 21:51:20 hemna Exp $
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 *
 */

define("WIZARD_VISITED", "_wizard_visited");
define("WIZARD_STEP", "_wizard_step");
define("WIZARD_TO_STEP", "_wizard_to_step");
define("WIZARD_ID", "_wizard_id");
define("WIZARD_ACTION", "_wizard_action");

define("WIZARD_NEXT", "NEXT");
define("WIZARD_PREV", "PREV");
define("WIZARD_JUMP", "JUMP");
define("WIZARD_FINAL", "FINAL");

class FormWizard extends FormProcessor {

    /**
     * This holds the array of
     * step objects for the 
     * wizard
     */
    var $_steps = array();


    /**
     * Holds a bunch of state
     * variables
     */
    var $_vars = array("to_step" => 0,
                       "num_steps" => 0,
                       "on_confirm" => FALSE,
                       WIZARD_ID => NULL );

    /**
     * The constructor
     *
     */
    function FormWizard() {
        user_error(__CLASS__."::".__FUNCTION." - this class isn't done yet.");
        $this->_session_test();
        $this->set_form_name( "form_wizard" );
        $this->set_form_action( $_SERVER["PHP_SELF"] );

        //let the child class add the steps
        $this->user_setup();

        //init our vars
        $this->_init();

        //Set up the Validation object
        //and the FormErrors object to
        //be used by this form.
        $this->setup_validation();

        //set the current step
        $this->_set_step();

        //now process the form
        $this->_process_form();

        //now we need to process the current step.
    }


    /**
     * This function renders the 
     * FormWizard
     *
     */
    function render($indent_level=0, $output_debug=0) {
        $container = container();

        //add the JS
        $container->add( $this->_build_js() );

        $container->add( $this->_build_toolbar(),
                         html_br(2) );

        if ($this->_has_errors) {
            //we need to render the form errors
            //and then the form
            $container->add( $this->render_error($indent_level, $output_debug) );
        } else {
            //there are no errors!
            ddd( "have we visited?" );
            //ddd( $_REQUEST );
            if (@$_REQUEST[FORM_VISITED] == 1) {
                //looks like the form has been processed?
                ddd( "confirmed = ".$this->_confirmed );
                ddd( "curr step = ".$this->_current_step() );
                if (!$this->_confirmed && $this->_vars["on_confirm"]) {
                    ddd("FINAL DUDE!");
                    $container->add( $this->render_confirm($indent_level, $output_debug) );
                } else {
                    //Looks like the action worked
                    $success = $this->_form_content->form_success();
                    
                    if ($this->_form_success_render) {
                        $container->add( $this->render_form($indent_level, $output_debug, $success) );
                    } else {
                        if (method_exists($success,"render")) {
                            //looks like this is an object.
                            //we'll assume it has a render function.
                            $container->add( $success->render($indent_level, $output_debug) );
                        } else {
                            //since its not an object,
                            //lets just display it.
                            $container->add( $success );
                        }
                    }
                }
            } else {
                $container->add( $this->render_form($indent_level, $output_debug) );
            }
        }

        return $container->render($indent_level, $output_debug);
    }


    /**
     * This method does the logic of
     * doing the form processing
     */
    function _process_form() {
        //Has this step been visited yet?

        if (!$this->_is_step_visited($this->_current_step()) &&
            $this->_current_step() <= $this->_vars["num_steps"]) {
            $this->_form_content->form_init_data();
        }

        //we only need to process the form
        //if it has been visited. Otherwise
        //it just gets rendered.
        if (@$_REQUEST[FORM_VISITED] == 1) {
            ddd("PROCESS STEP ".$this->_current_step());
            $this->_form_content->set_action($_REQUEST[FORM_ACTION]);

            //let see if this was a confirmation page.
            if ( @$_REQUEST[WIZARD_ACTION] == WIZARD_FINAL ) {
                //looks like this was a submit on a
                //confirmation page.  we don't need
                //to do form field validation.
                $this->_confirmed = TRUE;
                for ($i=0; $i<=$this->_vars["num_steps"]-1; $i++) {
                    $this->_has_errors = !$this->_steps[$i]["form"]->form_action();
                }
            } else {
                //we haven't been confirmed, so we
                //need to validate the form.
                if ($this->can_validate()) {
                    //looks like we should do validation
                    $this->do_validation();
                }
                if (!$this->_has_errors) {
                    //no errors were found
                    //make sure we don't have any backend errors
                    $this->_has_errors = !$this->_form_content->form_backend_validation();
                    if (!$this->_has_errors) {
                        //ok this step validated.  lets display the next.
                        //mark this step as visited
                        $current_step = $this->_current_step();
                        $this->_step_visited( $current_step );
                        ddd( "CURRENT STEP ".$current_step);

                        switch ($_REQUEST[WIZARD_ACTION]) {
                        case WIZARD_NEXT:                                                       
                            ddd("NEXT");
                            if ($current_step == $this->_vars["num_steps"]) {
                                //we need to show the confirmation
                                //don't process
                                $this->_vars["on_confirm"] = TRUE;
                                ddd("ASS");
                            } else {
                                $this->_set_current_step($current_step+1);
                                unset($_REQUEST[FORM_VISITED]);
                                $this->_form_content = &$this->_steps[$this->_current_step()-1]["form"];
                                $this->_process_form();
                            }                            
                            break;

                        case WIZARD_PREV:
                            $this->_set_current_step($current_step-1);
                            unset($_REQUEST[FORM_VISITED]);
                            $this->_form_content = &$this->_steps[$this->_current_step()-1]["form"];
                            ddd("PREV");
                            $this->_process_form();
                            break;
                        }
                    }
                }
            }
        }
        ddd("bail");
    }


    /**
     * This function renders the confirmation
     * page.  This page sits in between the
     * front end form, and the action handler.
     * This only gets called after a form
     * and its data has been successfully
     * validated.
     *
     * @param int - $indent_level
     * @param int - $output_debug
     *
     * @return string - the raw html
     */
    function render_confirm( $indent_level, $output_debug ) {
        ddd("BUILD CONFIRM");
        //build the $this->_form object.
        $this->_build_form_tag();

        //add the confirm object/html
        for($i=0; $i<=$this->_vars["num_steps"]-1; $i++) {
            $title = "Step ".($i+1)." : ".$this->_steps[$i]["title"];
            $this->_form->add( $this->_steps[$i]["form"]->form_confirm($title, FALSE),
                               html_br(2));
        }
        //$confirm = &$this->_form_content->form_confirm( $this->data );
        //$this->_form->add_reference( $confirm );

        //ok add all of the submitted data as hidden form fields
        $this->_add_confirm_data();

        //Ok lets add our hidden vars
        $this->__hidden_fields();

        return $this->_form->render($indent_level, $output_debug);
    }

    /**
     * A subclass can override this function
     * to setup the class variables after
     * the constructor.  The constructor
     * automatically calls this function.
     *
     */
    function user_setup() {
        trigger_error("FormWizard::user_setup() - ".
                      "child class must override this method ".
                      "to add the wizard steps");
    }


    /**
     * This adds a step to the wizard
     *
     * @param string - the title for the step
     * @param string - the description for the step
     * @param string - the help url for the step (if any)
     * @param FormContent - the form content object
     *                      that is the step.
     */
    function add_step( $title, $desc, $help, &$step ) {
        $this->_steps[] = array("title" => $title,
                                "desc" => $desc,
                                "help" => $help,
                                "form" => &$step);
        $this->_vars["num_steps"]++;
    }


    /**
     * This function initializes all of the fields we 
     * need to keep track of for the internal state
     * of the wizard.  It also walks each of the
     * step FormContent objects and initializes them.
     * 
     * We save some of the state of the wizard in 
     * the session.
     */
    function _init() {
        if (!isset($_REQUEST[WIZARD_VISITED])) {

            $this->_vars[WIZARD_ID] = uniqid("wizard_");
            ddd( $this->_vars );

            $this->_init_session();            
            $this->_vars["to_step"] = 2;
        } else {
            $this->_vars[WIZARD_ID] = $_REQUEST[WIZARD_ID];
            $current_step = $this->_current_step();
            $this->_vars["to_step"] = $current_step++;

            //if ($this->_vars["current_step"] == count($this->_steps)) {
            //    $this->_vars["to_step"] = WIZARD_FINAL;
            //} else {
            //    $this->_vars["to_step"] = WIZARD_NEXT;
            //}                        
        }
        //ddd( $_SESSION );

        //initialize all of the Forms
        //so they retain their data.
        for ($i=0; $i<=$this->_vars["num_steps"]-1; $i++) {
            $this->_steps[$i]["form"]->form_init_elements();
        }

    }

    /**
     * This function sets the _form_content
     * object for the current step we are operating on.
     * The parent FormProcessor needs this object set 
     * in order to process the step correctly.
     *
     */
    function _set_step() {
        $this->_form_content = &$this->_steps[$this->_current_step()-1]["form"];
    }

    function __hidden_fields() {

        //add all of the other steps fields
        //we need to add all the previous visted steps
        //fields so we save em.
        $step_count = 1;
        foreach( $this->_steps as $step ) {
            if ($step_count != $this->_current_step()) {
                $this->_form_content = &$step["form"];
                $this->_add_confirm_data();
            }
            $step_count++;
        }

        if (isset($_REQUEST[WIZARD_ACTION]) &&
            $_REQUEST[WIZARD_ACTION] == WIZARD_FINAL) {
            $this->_set_step();
        }

        parent::__hidden_fields();

        //$this->_form->add( form_hidden(WIZARD_STEP, $this->_vars["current_step"]) );
        $this->_form->add( form_hidden(WIZARD_TO_STEP, $this->_vars["to_step"]) );
        $this->_form->add( form_hidden(WIZARD_ID, $this->_vars[WIZARD_ID]) );
        $this->_form->add( form_hidden(WIZARD_ACTION, WIZARD_NEXT) );
        $this->_form->add( form_hidden(WIZARD_VISITED, 1) );
    }


    /**
     * This builds the javascript needed for the
     * navigation of the wizard
     *
     * @return string
     */
    function _build_js() {
        $name = $this->_form_attributes["name"];
        $js = "
        function wizard_cancel_confirm(butname, txt) {
            if (confirm(txt)){
                document.$name.".WIZARD_ACTION.".value = butname;
                document.$name.submit();
            }
        }
        function wizard_submit(txt) {
            document.$name.".WIZARD_ACTION.".value = txt;
            document.$name.submit();
        }
        function wizard_submit2(txt, step) {
            document.$name.".WIZARD_ACTION.".value = txt;
            document.$name.".WIZARD_TO_STEP.".value = step;
            document.$name.submit();
        }";

        $script = html_script();
        $script->add( $js );
        return $script;
    }



    /**
     * This renders the toolbar/step table
     * for the navigation of the wizard
     */
    function _build_toolbar() {
        $current_step = $this->_current_step();
        if ($this->_vars["on_confirm"]) {
            $current_step++;
            $step_title = "Confirmation";
        } else {
            $step_title = $this->_steps[$current_step - 1]["title"];
        }

        $title = "Step ".$current_step." : ". $step_title;
        $table = new InfoTable($title, 500);

        //build the table of steps.
        $c = container();
        $step_num = 1;
        foreach( $this->_steps as $step ) {
            $c->add( $this->_build_step_image( $step_num, $step["title"] ) );
            
            if ($step_num != $this->_vars["num_steps"]) {
                $arrow = html_img("/phphtmllib/images/wizard/arrow.png");
                $arrow->set_style("vertical-align:super");
                $c->add( $arrow );
            }
            
            $step_num++;
        }

        //add the confirmation step
        $c->add( $arrow );
        $c->add( $this->_build_step_image( $step_num, "Confirmation" ) );


        $tr = html_tr("", $c );
        $tr->set_style("text-align: center");
        $table->add_row( $tr );

        //now show the description
        if ($this->_vars["on_confirm"] == true) {
            $desc = "Confirmation";
        } else {
            $desc = $this->_steps[$current_step - 1]["desc"];
        }
        $tr = html_tr("", $desc );
        $tr->set_style("text-align: center");
        $table->add_row( $tr );

        //now add the controls
        $c = html_div();
        $c->set_style("padding-top: 5px;");

        if ($current_step != 1) {
            $link = html_a("javascript:wizard_submit2('".WIZARD_PREV."',".($current_step-1).");", 
                           html_img("/phphtmllib/images/wizard/previous_step.png"));
            $c->add( $link );
        }

        if ($current_step != $this->_vars["num_steps"]) {
            $link = html_a("javascript:wizard_submit2('".WIZARD_NEXT."',".($current_step+1).");", 
                           html_img("/phphtmllib/images/wizard/next_step.png") );
            $c->add( $link );
        } else {
            $link = html_a("javascript:wizard_submit2('".WIZARD_FINAL."',".($current_step).");", 
                           html_img("/phphtmllib/images/wizard/finish_steps.png") );

            $c->add( _HTML_SPACE, _HTML_SPACE, $link);
        }


        $tr = html_tr("", $c );
        $tr->set_style("text-align: center;");
        $table->add_row( $tr );

        return $table;
    }


    /**
     * This function builds an image for a step #
     *
     * @param string - the step # to build
     * @return Atag object
     */
    function &_build_step_image( $step_num, $step_title ) {
        $title = "Step ".$step_num." ";

        $current_step = $this->_current_step();
        if ($this->_vars["on_confirm"]) {
            $current_step++;
        }

        if ($step_num == $current_step) {
            $title .= " (Current) : ".$step_title;
            $img = html_img("/phphtmllib/images/wizard/".$step_num."_red.png", 30, 30, 0, 
                            $title, NULL, $title);

        } else if ($this->_is_step_visited($step_num)) {
            $title .= " (Completed) : ".$step_title;
            $img =  html_img("/phphtmllib/images/wizard/".$step_num."_black.png", 30, 30 ,0,
                             $title, NULL, $title);

        } else {
            $title .= " (Not Completed) : ".$step_title;
            $img = html_img("/phphtmllib/images/wizard/".$step_num."_gray.png", 30,30,0,
                            $title, NULL, $title);
        }
        
        return $img;
    }



    /*****************************************/
    /*        SESSION RELATED METHODS        */
    /*****************************************/

    /**
     * This method initializes the session 
     * variable that we use
     *
     */
    function _init_session() {
        //create a unique id for this wizard 
        //so we can have multple wizards 
        //running per session.
        $_SESSION[$this->_vars[WIZARD_ID]] = array();
        $_SESSION[$this->_vars[WIZARD_ID]];
        $this->_set_current_step(1);
        
        //mark all steps as NOT visited
        for ($i=0; $i<=$this->_vars["num_steps"]-1; $i++) {
            $this->_step_visited($i, FALSE);
        }
    }

    /**
     * This returns the current step id
     * from the session
     *
     */
    function _current_step() {
        return $_SESSION[$this->_vars[WIZARD_ID]]["current_step"];
    }

    /**
     * This sets the current step id
     *
     * @param int - the new step #
     */
    function _set_current_step($step) {
        ddd( "SET STEP ".$step);
        $_SESSION[$this->_vars[WIZARD_ID]]["current_step"] = $step;
    }


    /**
     * This sets the state variable for the 
     * step to let us know it has been visited or not
     *
     * @param int - the step to mark
     * @param boolean - TRUE = visited
     */
    function _step_visited($step_num, $visited=TRUE) {
        $_SESSION[$this->_vars[WIZARD_ID]]["visited_steps"][$step_num] = $visited;
    }

    /**
     * This tests to see if the step has been visited or not.
     *
     * @param int - the step to mark
     * @return boolean - TRUE = visited
     */
    function _is_step_visited($step_num) {
        if (isset($_SESSION[$this->_vars[WIZARD_ID]]["visited_steps"][$step_num])) {
            return $_SESSION[$this->_vars[WIZARD_ID]]["visited_steps"][$step_num];
        } else {
            return FALSE;
        }        
    }

    /**
     * This function cleans up the saved Session state
     * for the wizard.  This gets called when we have
     * completed the wizard w/o errors.
     *
     */
    function _clean() {
        unset($_SESSION[$this->_vars[WIZARD_ID]]);
    }

    /**
     * This ensures that we have sessions started
     * 
     */
    function _session_test() {
        if (!session_id()) {
            //we have to have sessions started.
            session_start();
        }
    }
}
?>
