<?php
/**
 * This file contains the base FECheckBox class.
 *
 * $Id: FECheckBox.inc,v 1.12 2003/07/18 17:59:21 hemna Exp $
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markosyan <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 *
 */

/**
 * This is the CheckBox FormElement which builds a
 * input field of type="checkbox". It has no validation method.
 *
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markossian <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 */
class FECheckBox extends FormElement {

    /**
     * Holds the checkbox text
     *
     */
    var $_text = NULL;

    /**
     * The constructor
     *
     * @param label string - text label for the element
     * @param string text - checkbox text to be displayed
     */
    function FECheckBox($label, $text) {
        $this->FormElement($label, false);
        $this->_text = $text;
    }

    /**
     * This provides a method
     * for the FormContent
     * to get access to the
     * text associated with a
     * field.  This is only available
     * on FormElements that have text
     * associated with a field.
     * It is used during Confirmation
     *
     * @param mixed - the value to look up
     * @return string - the text associated
     */
    function get_value_text($value) {
        if ($value != NULL) {
            return $this->_text;
        } else {
            return NULL;
        }        
    }

    /**
     * This function builds and returns the
     * form element object
     *
     * @return object
     */
    function get_element() {

        $c = form_active_checkbox($this->get_element_name(),
                                  $this->_text,
                                  $this->get_value(),
                                  "form_element");

        return $c;
    }
}

/**
 * This is the CheckBoxList FormElement which builds a
 * list of checkboxes inside a scrollable DIV.
 * It has no validation method.
 *
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markossian <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 */
class FECheckBoxList extends FEMultiListBox {

    /**
     * This function builds and returns the
     * form element object
     *
     * @return object
     */
    function get_element() {

        if ($this->_height || $this->_width) {
            $this->set_style_attribute("overflow", "auto");
            $this->set_style_attribute("border", "1px inset");
            $this->set_style_attribute("background-color", "white");
        }

        $attributes = $this->_build_element_attributes();
        unset( $attributes["name"] );
        $c = new DIVtag($attributes);

        $element_name = $this->get_element_name();
        $selected_values = $this->get_value();

        $x=0;
        foreach ($this->_data_list as $text=>$value) {
            $name = str_replace("[]", "[$x]", $element_name);
            $x++;
            $attributes = array("type"=>"checkbox",
                                "name"=>$name,
                                "value"=>$value);

            if (is_array($selected_values) && in_array($value, $selected_values))
                $attributes[] = "checked";

            
            $checkbox = new INPUTtag($attributes);

            $js_action = "javascript:elements['" . $name . "'].checked=!elements['".$name."'].checked;";
            $a_attributes = array("href" => "javascript:void(0)",
                                  "onClick" => $js_action);
            $a = new Atag($a_attributes, htmlspecialchars($text), FALSE);

            $check = container( $checkbox, $a );
            $check->set_collapse();

            $c->push($check, html_br());
        }

        return $c;
    }
}
?>
