<?php
/**
 * This file contains the FEListBox, FEMultiListBox 
 *
 * $Id: FEListBox.inc,v 1.5 2003/07/17 02:05:20 hemna Exp $
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markosyan <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 *
 */

/**
 * This is the ListBox FormElement which builds a 
 * select field with all of its options. 
 * It has no validation method.
 * 
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markossian <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 */
class FEListBox extends FEDataList {

    /**
     * This function builds and returns the
     * form element object
     *
     * @return object
     */
    function get_element() {

        $attributes = $this->_build_element_attributes();

        if ($this->_height) {
            $attributes["size"] = 5;
        }

        $selected_value = $this->get_value();

        $tag = new SELECTtag($attributes);

        foreach ($this->_data_list as $name=>$value) {

            $attributes = array("value"=>$value);
            if ($value == $selected_value) $attributes[] = "selected";

            $tag->add(new OPTIONtag($attributes, $name));
        }
        return $tag;
    }
}

/**
 * Build a Yes/No Select box
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markossian <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 */
class FEYesNoListBox extends FEListBox {

    /**
     * The Constructor
     * 
     * @param label string - text label for the element
     * @param bool required - is this a required element
     * @param array data_list - list of data elements (name=>value)
     * @param int required - element width in characters, pixels (px), percentage (%) or elements (em)
     * @param string - the value to use for the 'yes' radio
     *                 NOTE: default is 'yes'
     * @param string - the value to use for the 'no' radio
     *                 NOTE: default is 'no'
     */
    function FEYesNoListBox($label, $required = TRUE, $width = NULL, $height = NULL,
                            $yes_value="yes", $no_value="no") {
        $options = array("Yes" => $yes_value, "No" => $no_value);
        $this->FEListBox($label, $required, $width, $height, $options);
    }
}
 

/**
 * This is the MultiListBox FormElement which builds a 
 * select field with all of its options.  It enables
 * the ability to have multiple selections.
 * It has no validation method.
 * 
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markossian <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 */
class FEMultiListBox extends FEListBox {


    /**
     * This function creates element name
     * used in the form based on the text label
     * or any other parameters
     *
     * Overriding things function to make sure
     * an array is created instead of a single variable
     */
    function create_element_name() {

        parent::create_element_name();

        $this->_element_name .= "[]";
    }

    /**
     * This function builds and returns the
     * form element object
     *
     * @return object
     */
    function get_element() {

        $attributes = $this->_build_element_attributes();

        $attributes[] = "multiple";

        if ($this->_height) {
            $attributes["size"] = 5;
        }

        $selected_values = $this->get_value();

        $tag = new SELECTtag($attributes);

        foreach ($this->_data_list as $name=>$value) {

            $attributes = array("value"=>$value);
            if (is_array($selected_values) && in_array($value, $selected_values)) $attributes[] = "selected";

            $tag->add(new OPTIONtag($attributes, $name));
        }
        return $tag;
    }
}
?>
