<?php

/**
 * This file contains the Form Element child classes
 * that deal primarily with numbers.
 *
 * $Id: FENumbers.inc,v 1.2 2003/07/18 01:23:43 hemna Exp $
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markosyan <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 *
 */

require_once($phphtmllib."/form/form_elements/FEText.inc");

/**
 * This is the FormElement which builds a 
 * text input field that validates
 * It validates as is_number().
 * 
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markossian <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 */
class FENumber extends FEText {

    /**
     * This method validates the data
     * for this Form Element.
     *
     * It validates as is_float().
     * @param FormValidation object.
     */
    function validate(&$_FormValidation) {
        if (!$_FormValidation->is_number($this->get_value())) {
            $this->set_error_message( $_FormValidation->get_error_message() );
            return FALSE;
        }
        return TRUE;
    }
}

/**
 * This is the float FormElement which builds a 
 * text input field.
 * It validates as is_float().
 * 
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markossian <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 */
class FENumberFloat extends FEText {

    /**
     * This method validates the data
     * for this Form Element.
     *
     * It validates as is_float().
     * @param FormValidation object.
     */
    function validate(&$_FormValidation) {
        if (!$_FormValidation->is_float($this->get_value())) {
            $this->set_error_message( $_FormValidation->get_error_message() );
            return FALSE;
        }
        return TRUE;
    }
}

/**
 * This is the Price FormElement which builds a 
 * text input field.
 * It validates as is_price().
 * 
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markossian <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 */
class FENumberPrice extends FEText {

    /**
     * This method validates the data
     * for this Form Element.
     *
     * It validates as is_price().
     * @param FormValidation object.
     */
    function validate(&$_FormValidation) {
        if (!$_FormValidation->is_price($this->get_value())) {
            $this->set_error_message( $_FormValidation->get_error_message() );
            return FALSE;
        }
        return TRUE;
    }
}

/**
 * This is the Number Range FormElement which builds a 
 * text input field.
 * It validates as is_within_rage().
 * 
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @author Suren Markossian <suren@bcsweb.com>
 * @package phpHtmlLib
 * @subpackage FormProcessing
 *
 * @copyright LGPL - See LICENCE
 */
class FENumberInRange extends FEText {

    /**
     * The minimum #
     */
    var $_min = 0;
    /**
     * The maximum #
     */
    var $_max = 100;

    /**
     * Add the range to the label automatically?
     */
    var $_label_flag = TRUE;

    /**
     * The constructor
     *
     * @param label string - text label for the element
     * @param bool required - is this a required element
     * @param int required - element width in characters, pixels (px), percentage (%) or elements (em)
     * @param int maximum number of chars allowed to type in the field
     * @param int the minimum value allowable
     * @param int the maximum value allowable
     * @param boolean - add the range to the label automatically?
     * 
     */
    function FENumberInRange($label, $required = TRUE, $width = NULL, 
                           $maxlength = NULL, $min=0, $max=100, $label_flag=TRUE) {
        $this->FEText($label, $required, $width, $maxlength);
        $this->_min = $min;
        $this->_max = $max;
        $this->_label_flag = $label_flag;
    }

    function get_label() {

        $label = $this->get_label_text();

        if ($this->_label_flag) {
            $label .= " (".$this->_min."-".$this->_max.")";
        }

        if ($this->is_required()) $label .= ' ' . $this->get_required_symbol();

        $span = html_span("formlabel", $label);

        if ($this->has_error()) {
            $span->set_tag_attribute("style","color:red;");
        }

        return $span;
    }

    /**
     * This method validates the data
     * for this Form Element.
     *
     * It validates as is_price().
     * @param FormValidation object.
     */
    function validate(&$_FormValidation) {
        if (!$_FormValidation->is_range($this->get_value(), NULL, $this->_min, $this->_max)) {
            $this->set_error_message( $_FormValidation->get_error_message() );
            return FALSE;
        }
        return TRUE;
    }
}

?>
