<?php
/**
 * This file contains the PageWidget class
 *
 * $Id: PageWidget.inc,v 1.3 2002/09/25 01:36:00 hemna Exp $
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @package phpHtmlLib
 */

/**
 * Make sure we have the required parent class
 */ 
require_once($phphtmllib."/widgets/HTMLPageClass.inc");

/**
 * This class is used to build content 
 * for an entire page.  It uses the
 * HTMLPageClass widget from phphtmllib
 * to render the final output.
 *
 * @author Walter A. Boring IV <waboring@buildabetterweb.com>
 * @package phpHtmlLib
 */
class PageWidget extends HTMLPageClass {

	/** CLASS VARS **/

	/**
	 * This enables the ability to view the
	 * source of a page bu setting debug=1
	 * in the query string.
	 *
	 */
	var $_enable_debug = FALSE;


    /**
     * holds the page title text for
     * a page
     *
     */
    var $_title_text = NULL;


	/**
	 * Constructor:
	 *
     * @param   mixed  - $title Title string or TITLEtag object for the page.
     * @param   string - one of 3 types of html to render.  Setting this will
     *                   make the object declare the gobal define which tells
     *                   all of the tag objects what type of html tags to render.
     *                   some tags support special features.  such as the <IMG>
     *                   tag.  If xhtml is selected, the the IMGtag object and all
     *                   utility functions will not render "border=0" as a default
     *                   attribute, since this is not proper xhtml.
     *                   "html" - HTML 4.0 (default)
     *                   "xhtml_transitional" - render xhtml instead of html
     *                                        - doctype is XHTML transitional.
     *                   "xhtml_strict" - render xhtml instead of html 4.0.
     *                                  - doctype is XHTML strict.
	 * @param   int   - one of 2 types.  INDENT_NICE or INDENT_LEFT_JUSTIFY
	 *                  This tells the page how to render the indenting of the
	 *                  output.  By default it is set to INDENT_NICE, which nicely
	 *                  indents each nested tag.  You can have all tags rendered
	 *                  left justified (smaller size in output) by using 
	 *                  INDENT_LEFT_JUSTIFY
	 *
	 */
	function PageWidget( $title, $render_type = HTML, $indent_style=INDENT_NICE ) {		

		if ( defined("DEBUG") && 
             (isset($_GET["debug"]) || 
              isset($_POST["debug"]) ) ) {
			$this->enable_debug( TRUE );
		}
        //save the title for later.
        $this->_title_text = $title;

		//call the parent's constructor
		$this->HTMLPageClass( $title, $render_type, $indent_style );
	}

    /**
     * gets the current title of the page.
     *
     * @return string
     */
    function get_title() {
        return $this->_title_text;
    }

	/**
	 * This function is used to build 
	 * addition head content that isn't 
	 * built by the HTMLPageClass parent
	 * class by default.
	 * NOTE: you can add addition content
	 *       to the head in 1 of 2 ways.
	 *       1) inside the call return the
	 *          addition content in the
	 *          return $foo;
	 *       2) or use the HTMLPageClass'
	 *          $this->add_head_content()
	 *          from within the head_content()
	 *          call.
	 *
	 * @return mixed.
	 */ 
	function head_content() {
		return NULL;
	}


	/**
	 * This function is meant to be overridden
	 * by the child class.  
	 * This provides all of the content
	 * for the page.
	 * NOTE: You add the content to the 
	 *       body in 1 of 2 ways.
	 *       1) return the content from this
	 *          call.
	 *       2) inside the call, you can
	 *          just call $this->add();
	 *          and then return NULL;
	 *
	 * @return mixed.
	 */
	function body_content() {
		return NULL;
	}


	/**
	 * This function is used to save
	 * a frameset to the page.  This will
	 * automatically output a properly
	 * formatted 
	 */
	function frameset() {
		return NULL;
	}

	/**
	 * This function is called to build
	 * any JavaScript that is needed in the
	 * <HEAD> portion of a document.
	 *
	 * @return string - the raw JS code to be
	 *                  put inside the <head>
	 */
	function head_javascript() {
		return NULL;
	}


	/**
	 * This sets the debug option for
	 * the HTMLPageClass
	 *
	 * @param boolean TRUE for on, FALSE for off
	 */
	function enable_debug( $flag = TRUE ) {
		$this->_enable_debug = $flag;
	}


	/**
	 * This is the function that renders the HTML
	 * for this widget.
	 *
	 * @return string - the HTML
	 */
	function render() {

		//test to see if they want debugging of
		//output enabled.
		if ( $this->_enable_debug ) {
			if ( isset($_GET["debug"]) ) {
				$this->set_text_debug( TRUE );
			}
		}

		//check to see if they want to render a frameset
		$frameset = $this->frameset();
		if ( $frameset != NULL ) {
			//add and set the page output
			//to be a frameset.
			$this->set_frameset( $frameset );
		} else {

			//Try and get some more head content
			$content = "";
			$content = $this->head_content();
			if ( $content != "" ) {
				$this->add_head_content( $content );
			}

			//try and get the body content.
			//the user could just have added
			//the data manually.
			$content = "";
			$content = $this->body_content();
			if ( $content != "" ) {
				$this->add( $content );
			}
		}

		//Lets see if they have any javascript 
		//for the head
		$js = $this->head_javascript();
		if ( $js != NULL ) {
			$this->add_head_js( $js );
		}


		return HTMLPageClass::render();
	}
}
?>
